@@ -25,6 +25,7 @@
 #include <QStandardItem>
 #include <QStandardItemModel>
 #include <qquickitem.h>
+#include <QRect>
 
 const static int sMargin = 0;
 const static int sSnapArea = 20;
@@ -102,8 +103,6 @@ void QMLOutput::setLeftDockedTo(QMLOutput *output)
 
     m_leftDock = output;
     Q_EMIT leftDockedToChanged();
-
-    update();
 }
 
 QMLOutput *QMLOutput::leftDockedTo() const
@@ -124,8 +123,6 @@ void QMLOutput::setTopDockedTo(QMLOutput *output)
 
     m_topDock = output;
     Q_EMIT topDockedToChanged();
-
-    update();
 }
 
 QMLOutput *QMLOutput::topDockedTo() const
@@ -146,8 +143,6 @@ void QMLOutput::setRightDockedTo(QMLOutput *output)
 
     m_rightDock = output;
     Q_EMIT rightDockedToChanged();
-
-    update();
 }
 
 QMLOutput *QMLOutput::rightDockedTo() const
@@ -168,8 +163,6 @@ void QMLOutput::setBottomDockedTo(QMLOutput *output)
 
     m_bottomDock = output;
     Q_EMIT bottomDockedToChanged();
-
-    update();
 }
 
 QMLOutput *QMLOutput::bottomDockedTo() const
@@ -308,6 +301,39 @@ void QMLOutput::setIsCloneMode(bool isCloneMode)
     Q_EMIT isCloneModeChanged();
 }
 
+void QMLOutput::dockToNeighbours()
+{
+    Q_FOREACH (QMLOutput *otherQmlOutput, m_screen->outputs()) {
+        if (otherQmlOutput == this) {
+            continue;
+        }
+
+        if (!otherQmlOutput->output()->isConnected() || !otherQmlOutput->output()->isEnabled()) {
+            continue;
+        }
+
+        const QRect geom = m_output->geometry();
+        const QRect otherGeom = otherQmlOutput->output()->geometry();
+
+        if (geom.left() - 1 == otherGeom.right()) {
+            setLeftDockedTo(otherQmlOutput);
+            continue;
+        }
+        if (geom.right() + 1 == otherGeom.left()) {
+            setRightDockedTo(otherQmlOutput);
+            continue;
+        }
+        if (geom.top() - 1 == otherGeom.bottom()) {
+            setTopDockedTo(otherQmlOutput);
+            continue;
+        }
+        if (geom.bottom() + 1 == otherGeom.top()) {
+            setBottomDockedTo(otherQmlOutput);
+            continue;
+        }
+    }
+}
+
 KScreen::ModePtr QMLOutput::bestMode() const
 {
     if (!m_output) {
@@ -542,12 +568,12 @@ void QMLOutput::moved()
  */
 void QMLOutput::updateRootProperties()
 {
-    const int transformedWidth = (m_output->isHorizontal() ? currentOutputWidth() : currentOutputHeight()) * m_screen->outputScale();
-    const int transformedHeight = (m_output->isHorizontal() ? currentOutputHeight() : currentOutputWidth()) * m_screen->outputScale();
+    const float transformedWidth = (m_output->isHorizontal() ? currentOutputWidth() : currentOutputHeight()) * m_screen->outputScale();
+    const float transformedHeight = (m_output->isHorizontal() ? currentOutputHeight() : currentOutputWidth()) * m_screen->outputScale();
 
-    const int transformedX = x() + (width() / 2) - (transformedWidth / 2);
-    const int transformedY = y() + (height() / 2) - (transformedHeight / 2);
+    const float transformedX = x() + (width() / 2.0) - (transformedWidth / 2.0);
+    const float transformedY = y() + (height() / 2.0) - (transformedHeight / 2.0);
 
-    setPosition(QPoint(transformedX, transformedY));
-    setSize(QSize(transformedWidth, transformedHeight));
+    setPosition(QPointF(transformedX, transformedY));
+    setSize(QSizeF(transformedWidth, transformedHeight));
 }
